xg_example: Get path to excelgesis example

Description Usage Arguments Value Examples

View source: R/xg_example.R

Description

excelgesis includes many sheets drawn from examples, tests, and issues on readxl, rexcel, and googlesheets. This function makes it easier to get these filepaths. You probably want to make a copy in, e.g., working directory before unpacking an example. Or specify the exdir in xg_unzip().

Usage

1

Arguments

x

Character. A regex that matches desired filename(s).

Value

Character vector of full file paths.

Examples

1
2
3
4
xg_example()
xg_example("iris-excel-xlsx.xlsx")
xg_example("datasets")
xg_example("missing")

Zombie-Technology/ER documentation built on Dec. 31, 2020, 6:36 p.m.