xg_linkify: Add and remove links in an unpacked xlsx directory

Description Usage Arguments Details Examples

View source: R/xg_linkify.R

Description

Things that make an unpacked xlsx less awful to navigate in the browser:

Usage

1
2
3

Arguments

path

Path to a directory corresponding to a single, unpacked xlsx, i.e. the output of xg_unzip() or, alternatively, a directory of such things.

Details

xg_linkify() does the above and xg_de_linkify() undoes it.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
file.copy(xg_example("datasets"), "datasets.xlsx")
res <- "datasets.xlsx" %>%
  xg_unzip() %>%
  xg_linkify()
xg_browse(res)

xg_de_linkify("datasets")

## clean up
unlink("datasets", recursive = TRUE)
file.remove("datasets.xlsx")

Zombie-Technology/ER documentation built on Dec. 31, 2020, 6:36 p.m.