Description Usage Arguments Value Examples
excelgesis includes many sheets drawn from examples, tests, and issues on
readxl, rexcel, and googlesheets. This function makes it easier to get these
filepaths. You probably want to make a copy in, e.g., working directory
before unpacking an example. Or specify the exdir in xg_unzip().
1 | xg_example(x = NULL)
|
x |
Character. A regex that matches desired filename(s). |
Character vector of full file paths.
1 2 3 4 | xg_example()
xg_example("iris-excel-xlsx.xlsx")
xg_example("datasets")
xg_example("missing")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.